setPhotoMode method

Future<bool?> setPhotoMode(
  1. bool isPhoto
)

Sets whether the native camera is in Photo mode. When true, continuous OCR is paused to save power and only runs on capture.

Implementation

Future<bool?> setPhotoMode(bool isPhoto) {
  return OcrPlatform.instance.setPhotoMode(isPhoto);
}